<?php

/**
 * @package     Extly.Components
 * @subpackage  com_autotweet - A powerful social content platform to manage multiple social networks.
 *
 * @author      Extly, CB. <team@extly.com>
 * @copyright   Copyright (c)2007-2019 Extly, CB. All rights reserved.
 * @license     https://www.gnu.org/licenses/gpl-3.0.html GNU/GPL
 * @link        https://www.extly.com
 */

defined('_JEXEC') or die;

/**
 * FacebookPhotoChannelHelper class.
 *
 * @package     Extly.Components
 * @subpackage  com_autotweet
 * @since       1.0
 */
class FacebookPhotoChannelHelper extends FacebookBaseChannelHelper
{
	/**
	 * sendMessage.
	 *
	 * @param   string  $message  Params
	 * @param   object  $data     Params
	 *
	 * @return	boolean
	 */
	public function sendMessage($message, $data)
	{
		$title = $data->title;
		$text = $data->fulltext;
		$url = $data->url;
		$orgUrl = $data->org_url;
		$imageUrl = $data->image_url;
		$mediaMode = $this->getMediaMode();

		$logger = AutotweetLogger::getInstance();
		$logger->log(JLog::INFO, 'sendFacebookMessage', $message);

		if (empty($imageUrl))
		{
			return array(
				true,
				'No photo.'
			);
		}

		$fbId = $this->getFbChannelId();
		$fbAlbumId = $this->get('fbalbum_id');
		$fbToken = $this->get('fbchannel_access_token');
		$fbToken = $this->matchToken($fbToken, $fbId);

		$imageUtil = ImageUtil::getInstance();
		$file = $imageUtil->downloadImage($imageUrl);

		if (!$file)
		{
			return array(
				true,
				'No photo.'
			);
		}

		$this->getApiInstance();
		$fileToUpload = $this->facebook->fileToUpload($file);

		// Photo object: /user/photos
		$arguments = array(
			'message' => $message,
			'source' => $fileToUpload
		);

		$isUserProfile = $this->isUserProfile();

		if ($isUserProfile)
		{
			$privacy = $this->get('sharedwith', 'EVERYONE');
			$privacy = array('value' => $privacy);
			$arguments['privacy'] = json_encode($privacy);
		}

		try
		{
			if ($fbAlbumId)
			{
				$photo = $this->callApiPost("/{$fbAlbumId}/photos", $arguments, $fbToken);
			}
			else
			{
				$photo = $this->callApiPost("/{$fbId}/photos", $arguments, $fbToken);
			}

			$msg = 'Facebook id: ' . $photo['id'];
			$result = array(
				true,
				$msg
			);
		}
		catch (Exception $e)
		{
			$result = array(
				false,
				$e->getCode() . ' - ' . $e->getMessage()
			);
		}

		$imageUtil->releaseImage($file);

		return $result;
	}
}
