<?php

/**
 * @package     Extly.Components
 * @subpackage  com_autotweet - AutoTweetNG posts content to social channels (Tumblr, Facebook, LinkedIn, etc).
 *
 * @author      Extly, CB. <team@extly.com>
 * @copyright   Copyright (c)2007-2019 Extly, CB. All rights reserved.
 * @license     https://www.gnu.org/licenses/gpl-3.0.html GNU/GPL
 * @link        https://www.extly.com
 */

defined('_JEXEC') or die;

/**
 * TelegramChannelHelper
 *
 * @package     Extly.Components
 * @subpackage  com_autotweet
 * @since       1.0
 */
class TelegramChannelHelper extends ChannelHelper
{
	protected $telegramClient = null;

	protected $bot_token = null;

	protected $chat_id = null;

	protected $is_auth = null;

	protected $me = null;

	/**
	 * ChannelHelper.
	 *
	 * @param   object  $channel   Params.
	 * @param   string  $botToken  Params.
	 */
	public function __construct($channel, $botToken = null)
	{
		parent::__construct($channel);

		if ($channel->id)
		{
			$this->bot_token = $this->channel->params->get('bot_token');
			$this->chat_id = $this->channel->params->get('chat_id');
		}

		if ($botToken)
		{
			$this->bot_token = $botToken;
		}
	}

	/**
	 * Internal service functions
	 *
	 * @return	object
	 */
	protected function getApiInstance()
	{
		if (!$this->telegramClient)
		{
			$this->telegramClient = new \XTP_BUILD\Telegram\Bot\Api($this->bot_token);
		}

		return $this->telegramClient;
	}

	/**
	 * isAuth()
	 *
	 * @param   string  $chatId  Param
	 *
	 * @return	bool
	 */
	public function isAuth($chatId = null)
	{
		if (empty($this->bot_token))
		{
			$this->bot_token = null;

			return false;
		}

		try
		{
			$this->getApiInstance();

			$response = $this->telegramClient->getMe();

			$botId = $response->getId();
			$firstName = $response->getFirstName();
			$username = $response->getUsername();

			if ((int) $botId)
			{
				$user = $response;

				if ($chatId)
				{
					$response = $this->telegramClient->sendChatAction(
						[
							'chat_id' => '@' . $chatId,
							'action' => 'typing'
						]
					);
				}

				return $user;
			}
			else
			{
				return false;
			}
		}
		catch (Exception $e)
		{
			$logger = AutotweetLogger::getInstance();
			$logger->log(JLog::ERROR, $e->getMessage());

			// Just in case, it is shown someday
			JFactory::getApplication()->enqueueMessage($e->getMessage(), 'error');
		}

		return false;
	}

	/**
	 * sendMessage
	 *
	 * @param   string  $message  Param
	 * @param   array   $data     Param
	 *
	 * @return	array
	 */
	public function sendMessage($message, $data)
	{
		$logger = AutotweetLogger::getInstance();
		$logger->log(JLog::INFO, 'sendTelegramMessage', $message);

		$isAuth = $this->isAuth();

		if (!$isAuth)
		{
			return array(
				false,
				JText::_('COM_AUTOTWEET_CHANNEL_TELEGRAM_NOT_AUTH_ERR')
			);
		}

		$result = array(false, 'Telegram Unknown Error', null);

		try
		{
			$this->getApiInstance();
			$chatId = '@' . $this->channel->params->get('chat_id');

			$response = $this->telegramClient->sendMessage(
				[
					'chat_id' => $chatId,
					'text' => $message
				]
			);

			$messageId = $response->getMessageId();

			$result = array(
				true
			);

			$result[] = 'OK - ' . $messageId;
		}
		catch (Exception $e)
		{
			return array(
				false,
				$e->getMessage()
			);
		}

		return $result;
	}

	/**
	 * includeHashTags
	 *
	 * @return  bool
	 */
	public function includeHashTags()
	{
		return $this->channel->params->get('hashtags', true);
	}

	/**
	 * getSocialUrl
	 *
	 * @param   object  $user  Param
	 *
	 * @return	string
	 */
	public function getSocialUrl($user)
	{
		return 'https://telegram.me/' . $user->getUsername();
	}
}

