<?php

/**
 * @package     Extly.Components
 * @subpackage  com_autotweet - A powerful social content platform to manage multiple social networks.
 *
 * @author      Extly, CB. <team@extly.com>
 * @copyright   Copyright (c)2007-2019 Extly, CB. All rights reserved.
 * @license     https://www.gnu.org/licenses/gpl-3.0.html GNU/GPL
 * @link        https://www.extly.com
 */

defined('_JEXEC') or die;

/**
 * TwitterChannelHelper
 *
 * @package     Extly.Components
 * @subpackage  com_autotweet
 * @since       1.0
 */
class TwitterChannelHelper extends ChannelHelper
{
	protected $twitter = null;

	/**
	 * sendMessage
	 *
	 * @param   string  $message  Param
	 * @param   array   $data     Param
	 *
	 * @return	bool
	 */
	public function sendMessage($message, $data)
	{
		$imageFile = null;

		try
		{
			$imageUrl = $data->image_url;
			$mediaMode = $this->getMediaMode();

			if ($mediaMode == 'message')
			{
				$result = $this->_sendTwitterMessage($message, null);
			}
			else
			{
				// Media modes: attachment - both
				if (!empty($imageUrl))
				{
					$imageFile = ImageUtil::getInstance()->downloadImage($imageUrl);
				}

				$result = $this->_sendTwitterMessage($message, $imageFile);
			}
		}
		catch (Exception $e)
		{
			$result = array(
				false,
				$e->getMessage()
			);
		}

		if ($imageFile)
		{
			ImageUtil::getInstance()->releaseImage($imageFile);
		}

		return $result;
	}

	/**
	 * hasWeight
	 *
	 * @return	bool
	 */
	public function hasWeight()
	{
		return true;
	}

	/**
	 * includeHashTags
	 *
	 * @return  bool
	 */
	public function includeHashTags()
	{
		return $this->channel->params->get('hashtags', true);
	}

	/**
	 * Internal service functions
	 *
	 * @return	object
	 */
	protected function getApiInstance()
	{
		if (!$this->twitter)
		{
			$this->twitter = new \XTP_BUILD\Abraham\TwitterOAuth\TwitterOAuth(
				$this->get('consumer_key'),
				$this->get('consumer_secret'),
				$this->get('access_token'),
				$this->get('access_token_secret')
			);
		}

		return $this->twitter;
	}

	/**
	 * _sendTwitterMessage
	 *
	 * @param   string  $statusMessage  Param
	 * @param   string  $imagefile      Param
	 *
	 * @return	array
	 */
	private function _sendTwitterMessage($statusMessage, $imagefile = null)
	{
		$logger = AutotweetLogger::getInstance();
		$logger->log(JLog::INFO, '_sendTwitterMessage: ' . $statusMessage . ' - ' . $imagefile);

		$connection = $this->getApiInstance();

		$parameters = [
			'status' => $statusMessage
		];

		if ($imagefile)
		{
			$logger->log(JLog::INFO, '_sendTwitterMessage media/upload ' . $imagefile);

			$media = $connection->upload('media/upload',
				['media' => $imagefile]
			);

			if (isset($media->error))
			{
				$message = 'Error ' . $connection->getLastHttpCode();

				$message = array(
					false,
					$message
				);

				return $message;
			}

			$parameters['media_ids'] = implode(',', [$media->media_id_string]);
		}

		$logger->log(JLog::INFO, '_sendTwitterMessage statuses/update', $parameters);

		$response = $connection->post('statuses/update', $parameters);

		if ($connection->getLastHttpCode() == 200)
		{
			$postUrl = $response->id_str;
			$postUrl = 'https://twitter.com/'
				. $response->user->screen_name . '/status/' . $postUrl;

			return array(
				true,
				'OK - ' . $postUrl
			);
		}

		if (isset($response->errors))
		{
			$error = array_shift($response->errors);
			$message = $error->code . ' - ' . $error->message;
		}
		else
		{
			$message = 'Error ' . $connection->getLastHttpCode();
		}

		$message = array(
			false,
			$message
		);

		return $message;
	}
}
