<?php

/**
 * @package     Extly.FacebookApp
 * @subpackage  ServerAuth - A powerful social content platform to manage multiple social networks.
 *
 * @author      Extly, CB. <team@extly.com>
 * @copyright   Copyright (c)2007-2019 Extly, CB. All rights reserved.
 * @license     https://www.gnu.org/licenses/gpl-3.0.html GNU/GPL
 * @link        https://www.extly.com
 */

defined('_JEXEC') or die;

// FacebookApp to authorize and grant permissions for the AutoTweet standard App or your own App

/**
 * FacebookApp class.
 *
 * @package     Extly.Components
 * @subpackage  com_autotweet
 * @since       1.0
 */
class FacebookApp
{
	const PERMS_API3 = 'public_profile,publish_pages,manage_pages';

	const PERMS_API3_PAGES_AND_GROUPS = 'public_profile,publish_pages,manage_pages,publish_to_groups,groups_access_member_info';

	public $APP_ID = null;

	public $APP_SECRET = null;

	public $login_url = null;

	public $facebook = null;

	/**
	 * getAppPermissions
	 *
	 * @return	void
	 */
	public static function getAppPermissions()
	{
		return self::PERMS_API3;

		return self::PERMS_API3_PAGES_AND_GROUPS;
	}

	/**
	 * getAppPermissions
	 *
	 * @return	void
	 */
	public static function getAppPermissionsAndGroups()
	{
		return self::PERMS_API3_PAGES_AND_GROUPS;
	}

	/**
	 * Init from request.
	 *
	 * @return	void
	 */
	public function init()
	{
		// Called form AutoTweet backend
		$this->APP_ID = filter_input(INPUT_GET, 'app_id', FILTER_SANITIZE_STRING);
		$this->APP_SECRET = filter_input(INPUT_GET, 'secret', FILTER_SANITIZE_STRING);

		if (((empty($this->APP_ID)) || ($this->APP_ID === 'My-App-ID')) && (defined('MY_APP_ID')))
		{
			$this->APP_ID = MY_APP_ID;
		}

		if (((empty($this->APP_SECRET)) || ($this->APP_SECRET === 'My-App-Secret')) && (defined('MY_APP_SECRET')))
		{
			$this->APP_SECRET = MY_APP_SECRET;
		}

		if (DEBUG_ENABLED)
		{
			echo '<div class="alert alert-block alert-error"><button data-dismiss="alert" class="close" type="button">×</button>';
			echo '<h2>Debug information part 1: request data</h2>';
			echo '<p>request: ';
			print_r($_REQUEST);
			echo '</p>';
			echo '<ul>';
			echo '<li>app id: ' . $this->APP_ID . '</li>';
			echo '<li>api secret: ' . $this->APP_SECRET . '</li>';
			echo '</ul>';
			echo '</div>';
		}

		$ok = !(empty($this->APP_ID) || empty($this->APP_SECRET));

		if ($ok)
		{
			$this->facebook = new facebookphpsdk\Facebook(
					array(
							'appId' => $this->APP_ID,
							'secret' => $this->APP_SECRET,
							'cookie' => true
				)
			);
		}

		return $ok;
	}

	/**
	 * Login.
	 *
	 * @return	void
	 */
	public function login()
	{
		$user = $this->facebook->getUser();

		if (empty($user) || !isset($_REQUEST['state']))
		{
			$ref = filter_input(INPUT_SERVER, 'HTTP_REFERER', FILTER_SANITIZE_URL);

			if (defined('MY_CANVAS_URL'))
			{
				$ref = MY_CANVAS_URL;
			}

			if (empty($ref))
			{
				echo '<div class="alert alert-block alert-error"><button data-dismiss="alert" class="close" type="button">×</button>';
				echo '<h2>HTTP_REFERER not available.</h2>';
				echo '<ul>';
				echo '<li>Please, enable the HTTP_REFERER or define MY_CANVAS_URL.</li>';
				echo '</ul>';
				echo '</div>';
			}

			$params = array(
							'redirect_uri' => $ref,
							'scope' => $this->getAppPermissions(),
							'state' => $this->APP_ID . ',' . $this->APP_SECRET . ',' . $ref
			);
			$this->login_url = $this->facebook->getLoginUrl($params);

			if (DEBUG_ENABLED)
			{
				echo '<div class="alert alert-block alert-error"><button data-dismiss="alert" class="close" type="button">×</button>';
				echo '<h2>Debug information part 2: login data</h2>';
				echo '<ul>';
				echo '<li>user: ' . print_r($user, true) . '</li>';
				echo '<li>state: ' . $_REQUEST['state'] . '</li>';
				echo '<li>login_url: ' . $this->login_url . '</li>';
				echo '</ul>';
				echo '</div>';
			}

			return false;
		}

		return true;
	}

	/**
	 * isFacebookBot.
	 *
	 * @return	boolean
	 */
	public static function isFacebookBot()
	{
		$httpUserAgent = isset($_SERVER['HTTP_USER_AGENT']) ? $_SERVER['HTTP_USER_AGENT'] : null;

		if ((strpos($httpUserAgent, "facebookexternalhit/") !== false))
		{
			return true;
		}

		if (strpos($httpUserAgent, "Facebot") !== false)
		{
			return true;
		}

		return false;
	}
}
