<?php

/**
 * @package     Extly.Components
 * @subpackage  PlgContentAutotweetOpenGraph - Plugin AutoTweet NG OpenGraph Tags-Extension for Joomla!
 *
 * @author      Extly, CB. <team@extly.com>
 * @copyright   Copyright (c)2007-2019 Extly, CB. All rights reserved.
 * @license     https://www.gnu.org/licenses/gpl-3.0.html GNU/GPL
 * @link        https://www.extly.com
 */

defined('_JEXEC') or die;

/**
 * OGSmartLoader
 *
 * @package     Extly.Components
 * @subpackage  com_autotweet
 * @since       1.0
 */
class OGSmartLoader
{
	public $item;

	/**
	 * __construct.
	 *
	 * @param   object  $item  Params
	 */
	public function __construct($item = null)
	{
		if (!$item)
		{
			$item = new OGItem;
		}

		$this->item = $item;
	}

	/**
	 * getItemByPost
	 *
	 * @param   object  $postId  Params
	 *
	 * @return	object
	 */
	public function getItemByPost($postId)
	{
		$db = JFactory::getDbo();
		$query = $db->getQuery(true);
		$query->select('*')
			->from('#__autotweet_posts')
			->where('id = ' . $db->q($postId))
			->setLimit(1);
		$db->setQuery($query);
		$post = $db->loadObject();

		if ($post)
		{
			$this->assignPost($post);
		}

		return $this->item;
	}

	/**
	 * getItem - Deprecated
	 *
	 * @return	object
	 */
	public function getItem()
	{
		return $this->getItemByUrl();
	}

	/**
	 * getItemByUrl
	 *
	 * @return	object
	 */
	public function getItemByUrl()
	{
		$currentBaseUrl = JUri::current();

		$db = JFactory::getDbo();
		$query = $db->getQuery(true);
		$query->select('*')
			->from('#__autotweet_posts')
			->where('org_url like ' . $db->q($currentBaseUrl . '%'))
			->order('ID desc')
			->setLimit(1);
		$db->setQuery($query);
		$post = $db->loadObject();

		if ($post)
		{
			$this->assignPost($post);
		}

		return $this->item;
	}

	/**
	 * assignPost
	 *
	 * @param   object  $post  Params
	 *
	 * @return	void
	 */
	protected function assignPost($post)
	{
		$currentUrl = JUri::getInstance()->toString();
		$post->xtform = EForm::paramsToRegistry($post);

		if (empty($this->item->title))
		{
			$this->item->title = $post->title;
		}

		if (empty($this->item->introtext))
		{
			$this->item->introtext = $post->fulltext;
		}

		if (empty($this->item->publish_up))
		{
			$this->item->publish_up = $post->created;
		}

		if (empty($this->item->modified))
		{
			$this->item->modified = $post->modified;
		}

		if (empty($this->item->firstContentImage))
		{
			$this->item->firstContentImage = $post->image_url;
			$this->item->introImage = $post->image_url;
			$this->item->fullTextImage = $post->image_url;
			$this->item->imageArray = array();
			$this->item->imageArray[] = $post->image_url;
		}

		if (empty($this->item->url))
		{
			$this->item->url = $currentUrl;
		}

		// $logger = AutotweetLogger::getInstance();
		// $logger->log(
		// 	JLog::INFO,
		// 	'OGSmartLoader post found ID: ' .
		// 		$post->id .
		// 		' Title: ' .
		// 		$this->item->title .
		// 		' Introtext: ' .
		// 		$this->item->introtext .
		// 		' Image: ' .
		// 		$this->item->firstContentImage
		// );
	}
}
