<?php

/**
 * @package     Extly.Components
 * @subpackage  com_autotweet - A powerful social content platform to manage multiple social networks.
 *
 * @author      Extly, CB. <team@extly.com>
 * @copyright   Copyright (c)2007-2019 Extly, CB. All rights reserved.
 * @license     https://www.gnu.org/licenses/gpl-3.0.html GNU/GPL
 * @link        https://www.extly.com
 */

defined('_JEXEC') or die;

/**
 * AutotweetBitlyService - AutoTweet bit.ly url short service.
 *
 * @package     Extly.Components
 * @subpackage  com_autotweet
 * @since       1.0
 */
class AutotweetBitlyService extends AutotweetShortservice
{
	/**
	 * getShortURL
	 *
	 * @param   string  $long_url  Param.
	 *
	 * @return	string
	 */
	public function getShortUrl($long_url)
	{
		$enc_url = urlencode($long_url);
		$service_call = 'http://api.bit.ly/v3/shorten?login=' . $this->data['bit_username']
		. '&apiKey=' . $this->data['bit_key'] . '&longUrl=' . $enc_url . '&format=json';

		$result = $this->callComplexService($service_call);

		$result_code = $result[0];
		$js = $result[1];

		if ((200 != $result_code) || (200 != (int) $js->status_code) || (!isset($js->data->url)) )
		{
			$short_url = null;
			$this->error_msg = $js->status_txt;
		}
		else
		{
			$short_url = $js->data->url;
		}

		if ( ($short_url) && (!RouteHelp::getInstance()->validateUrl($short_url)) )
		{
			$short_url = null;
			$this->error_msg = JText::sprintf(COM_AUTOTWEET_ERR_INVALID_SHORTURL, $short_url);
		}

		return $short_url;
	}
}
