<?php

/**
 * @package     Extly.Components
 * @subpackage  com_autotweet - A powerful social content platform to manage multiple social networks.
 *
 * @author      Extly, CB. <team@extly.com>
 * @copyright   Copyright (c)2007-2019 Extly, CB. All rights reserved.
 * @license     https://www.gnu.org/licenses/gpl-3.0.html GNU/GPL
 * @link        https://www.extly.com
 */

defined('_JEXEC') or die;

/**
 * AutotweetGooglService
 *
 * @package     Extly.Components
 * @subpackage  com_autotweet
 * @since       1.0
 */
class AutotweetGooglService extends AutotweetShortservice
{
	/**
	 * getShortURL
	 *
	 * @param   string  $longUrl  Param.
	 *
	 * @return	string
	 */
	public function getShortUrl($longUrl)
	{
		try
		{
			$shortUrl = null;
			$googleApiKey = EParameter::getComponentParam(CAUTOTWEETNG, 'google_api_key');

			$client = new XTP_Google_Client;
			$client->setDeveloperKey($googleApiKey);
			$service = new XTP_Google_Service_Urlshortener($client);

			$url = new XTP_Google_Service_Urlshortener_Url;
			$url->longUrl = $longUrl;

			$response = $service->url->insert($url);

			if (isset($response->id))
			{
				$shortUrl = $response->id;
			}
		}
		catch (Exception $e)
		{
			$this->error_msg = $e->getMessage();
		}

		if ( ($shortUrl) && (!RouteHelp::getInstance()->validateUrl($shortUrl)) )
		{
			$shortUrl = null;
			$this->error_msg = JText::sprintf(COM_AUTOTWEET_ERR_INVALID_SHORTURL, $shortUrl);
		}

		return $shortUrl;
	}
}
