<?php

/**
 * @package     Extly.Components
 * @subpackage  com_autotweet - A powerful social content platform to manage multiple social networks.
 *
 * @author      Extly, CB. <team@extly.com>
 * @copyright   Copyright (c)2007-2019 Extly, CB. All rights reserved.
 * @license     https://www.gnu.org/licenses/gpl-3.0.html GNU/GPL
 * @link        https://www.extly.com
 */

defined('_JEXEC') or die;

/**
 * AutotweetYourlsService
 *
 * @package     Extly.Components
 * @subpackage  com_autotweet
 * @since       1.0
 */
class AutotweetYourlsService extends AutotweetShortservice
{
	/**
	 * getShortURL
	 *
	 * @param   string  $long_url  Param.
	 *
	 * @return	string
	 */
	public function getShortUrl($long_url)
	{
		// Create the data to be encoded into JSON
		$requestData = array(
				'url'      => $long_url,
				'format'   => 'json',
				'action'   => 'shorturl',
				'signature' => $this->data['yourls_token']
		);

		$result = $this->callPostService($this->data['yourls_host'], $requestData);

		$result_code = $result[0];
		$output = $result[1];

		if ((200 != $result_code) || (!isset($output->shorturl)))
		{
			$short_url = null;
			$this->error_msg = '(' . $result_code . ')'
					. ' / ' . $output->status
					. ' - ' . $output->code;
		}
		else
		{
			$short_url = $output->shorturl;
		}

		if ( ($short_url) && (!RouteHelp::getInstance()->validateUrl($short_url)) )
		{
			$short_url = null;
			$this->error_msg = JText::sprintf(COM_AUTOTWEET_ERR_INVALID_SHORTURL, $short_url);
		}

		return $short_url;
	}
}
