<?php
/**
 * @package     Extly.Components
 * @subpackage  com_autotweet - A powerful social content platform to manage multiple social networks.
 *
 * @author      Extly, CB. <team@extly.com>
 * @copyright   Copyright (c)2007-2019 Extly, CB. All rights reserved.
 * @license     https://www.gnu.org/licenses/gpl-3.0.html GNU/GPL
 * @link        https://www.extly.com
 */

defined('_JEXEC') or die;

use XTP_BUILD\Extly\Infrastructure\Service\Cms\Joomla\ScriptHelper;

/**
 * AutotweetViewComposer
 *
 * @package     Extly.Components
 * @subpackage  com_autotweet
 * @since       1.0
 */
class AutotweetViewComposer extends AutoTweetDefaultView
{
	/**
	 * onAdd.
	 *
	 * @param   string  $tpl  Param
	 *
	 * @return	void
	 */
	public function onAdd($tpl = null)
	{
		$result = parent::onAdd($tpl);

		Extly::loadAwesome();
		JHtml::stylesheet('lib_extly/ng-table.min.css', false, true);
		JHtml::stylesheet('lib_extly/chosen.min.css', false, true);

		$root = JUri::root();
		ScriptHelper::addScriptDeclaration('var AUTOTWEETNG_JOOCIAL = '
			. (AUTOTWEETNG_JOOCIAL ? 'true' : 'false') . ';');

		$attribs = ['defer' => false, 'async' => false];
		ScriptHelper::addScript($root . 'media/lib_extly/js/backbone/underscore.min.js', 'text/javascript', $attribs);
		ScriptHelper::addScript($root . 'media/lib_extly/js/angular/angular.min.js', 'text/javascript', $attribs);
		ScriptHelper::addScript($root . 'media/lib_extly/js/angular/angular-resource.min.js', 'text/javascript', $attribs);
		ScriptHelper::addScript($root . 'media/lib_extly/js/angular/ng-table.min.js', 'text/javascript', $attribs);
		ScriptHelper::addScript($root . 'media/lib_extly/js/angular/ui-bootstrap-buttons.min.js', 'text/javascript', $attribs);
		ScriptHelper::addScript($root . 'media/lib_extly/js/utils/chosen.jquery.min.js', 'text/javascript', $attribs);
		ScriptHelper::addScript($root . 'media/lib_extly/js/angular/angular-chosen.min.js', 'text/javascript', $attribs);
		ScriptHelper::addScript($root . 'media/lib_extly/js/utils/md5.min.js', 'text/javascript', $attribs);

		// Load it in advance
		JHtml::script('lib_extly/utils/xtcronjob-expression-field-ng.js', false, true);

		ScriptHelper::addScriptVersion($root . 'media/lib_extly/js/extlycoreng.min.js', EXTLY_VERSION, $attribs);
		ScriptHelper::addScriptVersion($root . 'media/com_autotweet/js/composer.min.js', CAUTOTWEETNG_VERSION, $attribs);

		$platform = F0FPlatform::getInstance();
		$this->assign('editown', $platform->authorise('core.edit.own', $this->input->getCmd('option', 'com_foobar')));
		$this->assign('editstate', $platform->authorise('core.edit.state', $this->input->getCmd('option', 'com_foobar')));

		return $result;
	}
}
