<?php
/**
 * @package     Extly.Components
 * @subpackage  com_autotweet - A powerful social content platform to manage multiple social networks.
 *
 * @author      Extly, CB. <team@extly.com>
 * @copyright   Copyright (c)2007-2019 Extly, CB. All rights reserved.
 * @license     https://www.gnu.org/licenses/gpl-3.0.html GNU/GPL
 * @link        https://www.extly.com
 */

defined('_JEXEC') or die;

$session = JFactory::getSession();
$session->set('channelId', $this->item->id);
$channeltypeId = $this->input->get('channeltype_id', AutotweetModelChanneltypes::TYPE_LIOAUTH2_CHANNEL, 'cmd');

?>
<!-- com_autotweet_OUTPUT_START -->
<p style="text-align:center;">
	<span class="loaderspinner">&nbsp;</span>
</p>
<?php

	echo JText::_('COM_AUTOTWEET_CHANNEL_LIOAUTH2_DESC');

	$required = array('class' => 'required', 'required' => 'required');
	echo EHtml::textControl($this->item->xtform->get('consumer_key'), 'xtform[consumer_key]', 'COM_AUTOTWEET_CHANNEL_LIOAUTH2_CONSUMER_KEY', 'COM_AUTOTWEET_CHANNEL_LIOAUTH2_CONSUMER_KEY_DESC', 'consumer_key', 60, $required);
	echo EHtml::textControl($this->item->xtform->get('consumer_secret'), 'xtform[consumer_secret]', 'COM_AUTOTWEET_CHANNEL_LIOAUTH2_CONSUMER_SECRET', 'COM_AUTOTWEET_CHANNEL_LIOAUTH2_CONSUMER_SECRET_DESC', 'consumer_secret', 60, $required);

	$options = array();
	$options[] = array('name' => 'v1', 'value' => LiOAuth2ChannelHelper::API_v1);
	$options[] = array('name' => 'v2', 'value' => LiOAuth2ChannelHelper::API_v2);

	echo EHtmlSelect::btnGroupListControl(
		$this->item->xtform->get('li_api_version', LiOAuth2ChannelHelper::API_v1),
		'xtform[li_api_version]',
		'COM_AUTOTWEET_CHANNEL_LIOAUTH2_API_VERSION_LABEL',
		'COM_AUTOTWEET_CHANNEL_LIOAUTH2_API_VERSION_DESC',
		$options,
		'li_api_version'
	);

	$accessToken = null;
	$user = null;
	$userId = null;

	$authUrl = '#';
	$authUrlButtonStyle = 'disabled';
	$validationGroupStyle = 'hide';

	// New channel, not even saved
	if ($this->item->id == 0)
	{
		$message = JText::_('COM_AUTOTWEET_CHANNEL_LIOAUTH2_NEWCHANNEL_NOAUTHORIZATION');
		include_once 'auth_button.php';
	}
	else
	{
		$isCompanyChannel = ($channeltypeId == AutotweetModelChanneltypes::TYPE_LIOAUTH2COMPANY_CHANNEL);

		if ($isCompanyChannel) {
			$lioauth2ChannelHelper = new LiOAuth2CompanyChannelHelper($this->item);
		} else {
			$lioauth2ChannelHelper = new LiOAuth2ChannelHelper($this->item);
		}

		$isAuth = $lioauth2ChannelHelper->isAuth();

		// New channel, but saved
		if (($isAuth) && (is_array($isAuth)) && (array_key_exists('user', $isAuth)))
		{
			// We have an access Token!
			$user = $isAuth['user'];
			$userId = $user->id;
			$this->item->xtform->set('social_url', $lioauth2ChannelHelper->getSocialUrl($user));

			$validationGroupStyle = null;

			$accessToken = $this->item->xtform->get('access_token');

			include_once 'validation_button.php';
		}
		else
		{
			$message = JText::_('COM_AUTOTWEET_CHANNEL_LIOAUTH2_NEWCHANNEL_AUTHORIZATION');
			$authUrl = $lioauth2ChannelHelper->getAuthorizationUrl();

			if (empty($authUrl))
			{
				$authUrl = '#';
				$message = JText::_('COM_AUTOTWEET_CHANNEL_LIOAUTH2_NEWCHANNEL_NOAUTHORIZATION');
				include_once 'auth_button.php';
			}
			else
			{
				$authUrlButtonStyle = null;

				include_once 'auth_button.php';
				include_once 'validation_button.php';
			}
		}
	}
?>

<div class="alert">
	<button type="button" class="close" data-dismiss="alert">&times;</button>
	<ul class="unstyled">
		<li><i class="xticon xticon-thumbs-up"></i> <a
		href="https://www.extly.com/docs/autotweetng_joocial/tutorials/how-to-autotweet"
		target="_blank"> How to AutoTweet from Joomla in 5 <minutes></minutes></a></li>

		<li><i class="xticon xticon-youtube-play"></i> <a
		href="https://www.extly.com/docs/autotweetng_joocial/tutorials/how-to-autotweet#how-to-autotweet-from-joomla-to-linkedin-in-5-minutes-video"
		target="_blank"> How to autotweet from Joomla! to LinkedIn in 5 minutes - Video</a></li>
	</ul>
</div>

<!-- com_autotweet_OUTPUT_START -->
