<?php

/**
 * @package     Extly.Components
 * @subpackage  com_autotweet - A powerful social content platform to manage multiple social networks.
 *
 * @author      Extly, CB. <team@extly.com>
 * @copyright   Copyright (c)2007-2019 Extly, CB. All rights reserved.
 * @license     https://www.gnu.org/licenses/gpl-3.0.html GNU/GPL
 * @link        https://www.extly.com
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

defined('_JEXEC') or die();

// Load FOF if not already loaded
if (!defined('F0F_INCLUDED')) {
    $paths = array(
        (defined('JPATH_LIBRARIES') ? JPATH_LIBRARIES : JPATH_ROOT . '/libraries') . '/f0f/include.php',
        __DIR__ . '/fof/include.php',
    );

    foreach ($paths as $filePath) {
        if (!defined('F0F_INCLUDED') && file_exists($filePath)) {
            @include_once $filePath;
        }
    }
}

// Pre-load the installer script class from our own copy of FOF
if (!class_exists('F0FUtilsInstallscript', false)) {
    @include_once __DIR__ . '/fof/utils/installscript/installscript.php';
}

// Pre-load the database schema installer class from our own copy of FOF
if (!class_exists('F0FDatabaseInstaller', false)) {
    @include_once __DIR__ . '/fof/database/installer.php';
}

// Pre-load the update utility class from our own copy of FOF
if (!class_exists('F0FUtilsUpdate', false)) {
    @include_once __DIR__ . '/fof/utils/update/update.php';
}

// Pre-load the cache cleaner utility class from our own copy of FOF
if (!class_exists('F0FUtilsCacheCleaner', false)) {
    @include_once __DIR__ . '/fof/utils/cache/cleaner.php';
}

/**
 * Com_AutoTweetInstallerScript
 *
 * @package     Extly.Components
 * @subpackage  com_autotweet
 * @since       1.0
 */
class Com_AutoTweetInstallerScript extends F0FUtilsInstallscript
{
    /**
     * The component's name
     *
     * @var   string
     */
    protected $componentName = 'com_autotweet';

    /**
     * The title of the component (printed on installation and uninstallation messages)
     *
     * @var string
     */
    protected $componentTitle = 'AutoTweetNG PRO';

    /**
     * The minimum PHP version required to install this extension
     *
     * @var   string
     */
    protected $minimumPHPVersion = '5.5.9';

    /**
     * The minimum Joomla! version required to install this extension
     *
     * @var   string
     */
    protected $minimumJoomlaVersion = '3.3.0';

	/**
	 * The maximum Joomla! version this extension can be installed on
	 *
	 * @var   string
	 */
	protected $maximumJoomlaVersion = '4.9.99';

    /**
     * The list of extra modules and plugins to install on component installation / update and remove on component
     * uninstallation.
     *
     * @var   array
     */
    protected $installation_queue = array(
        // * modules => { (folder) => { (module) => { (position), (published) } }* }*
        'modules' => array(
            'admin' => array(
                'autotweet_latest' => array('cpanel', 0)
            ),
            'site' => array(
                'twfollow' => array('left', 0),
                'light_rss' => array('left', 0)
            )
        ),

        // * plugins => { (folder) => { (element) => (published) }* }*
        'plugins' => array(
                'system' => array(
                        'autotweetautomator' => 1,
                        'autotweetcontent'    => 1,
                        'autotweetsocialprofile' => 0
                ),
				'content' => array(
                        'autotweet_opengraph' => 0
                ),
                'autotweet' => array(
                        'autotweetpost' => 1
                )
        )
    );

    /**
     * The list of obsolete extra modules and plugins to uninstall on component upgrade / installation.
     *
     * @var array
     */
    protected $uninstallation_queue = array(
        // * modules => { (folder) => { (module) }* }*
        'modules' => array(
            'admin' => array(
				'joocial_menu'
            ),
            'site'  => array(
            )
        ),

        // * plugins => { (folder) => { (element) }* }*
        'plugins' => array(
			'ajax'    => array(
                'joocialwebpushmanifest'
            ),
			'editors-xtd'    => array(
                'joocialeditor'
            ),
			'installer'    => array(
                'autotweet'
            ),
			'system'    => array(
                'joocialgap',
				'joocialwebpush'
            )
        )
    );

    /**
     * Obsolete files and folders to remove from both paid and free releases. This is used when you refactor code and
     * some files inevitably become obsolete and need to be removed.
     *
     * @var   array
     */
    protected $removeFilesAllVersions = array(
        'files'   => array(
            // Deprecated
			'administrator/components/com_autotweet/controllers/gpluschannels.php',
			'administrator/components/com_autotweet/controllers/vkchannels.php',
            'administrator/components/com_autotweet/controllers/targets.php',
            'administrator/components/com_autotweet/helpers/channels/facebooklink.php',
            'administrator/components/com_autotweet/helpers/channels/gplus.php',
            'administrator/components/com_autotweet/helpers/channels/linkedin.php',
            'administrator/components/com_autotweet/helpers/channels/linkedinbase.php',
            'administrator/components/com_autotweet/helpers/channels/linkedincompany.php',
            'administrator/components/com_autotweet/helpers/oghelpers/k2article.php',
            'administrator/components/com_autotweet/helpers/oghelpers/vmarticle.php',
            'administrator/components/com_autotweet/helpers/oghelpers/zooarticle.php',
            'administrator/components/com_autotweet/helpers/route.php',
            'administrator/components/com_autotweet/models/targets.php',
            'administrator/components/com_autotweet/tables/target.php',
            'administrator/components/com_autotweet/views/composer/tmpl/1-0-link.php',
            'administrator/components/com_autotweet/views/composer/tmpl/1-1-image.php',
            'administrator/components/com_autotweet/views/composer/tmpl/1-2-scheduler.php',

            'media/com_autotweet/js/channel/collections/licompanies.js',
            'media/com_autotweet/js/channel/collections/livalidations.js',
            'media/com_autotweet/js/channel/models/licompany.js',
            'media/com_autotweet/js/channel/models/livalidation.js',
            'media/com_autotweet/js/channel/views/licompany.js',
            'media/com_autotweet/js/channel/views/livalidation.js',
            'media/com_autotweet/js/composer/agenda-controller.js',
            'media/com_autotweet/js/composer/agenda-service.js',
            'media/com_autotweet/js/composer/agendas-controller.js',
            'media/com_autotweet/js/composer/agendas-controller.min.js',
            'media/com_autotweet/js/composer/agendas-service.js',
            'media/com_autotweet/js/composer/agendas-service.min.js',
            'media/com_autotweet/js/composer/app.min.js',
            'media/com_autotweet/js/composer/directives.js',
            'media/com_autotweet/js/composer/directives.min.js',
            'media/com_autotweet/js/composer/editor-controller.js',
            'media/com_autotweet/js/composer/editor-controller.min.js',
            'media/com_autotweet/js/composer/jquery-extras.js',
            'media/com_autotweet/js/composer/message-controller.js',
            'media/com_autotweet/js/composer/request-helper.js',
            'media/com_autotweet/js/composer/requests-controller.js',
            'media/com_autotweet/js/composer/requests-controller.min.js',
            'media/com_autotweet/js/composer/requests-service.js',
            'media/com_autotweet/js/composer/requests-service.min.js',
            'media/com_autotweet/js/itemeditor.helper.js',
            'media/com_autotweet/js/itemeditor.helper.min.js',
            'media/com_autotweet/js/target.js',
            'media/com_autotweet/js/target.min.js',

            // Joocial Reset
            'administrator/components/com_autotweet/controllers/pinterestchannels.php',
            'administrator/components/com_autotweet/controllers/pagespeedchannels.php',
            'administrator/components/com_autotweet/controllers/bloggerchannels.php',
            'administrator/components/com_autotweet/controllers/calendar.php',
            'administrator/components/com_autotweet/controllers/evergreens.php',
            'administrator/components/com_autotweet/controllers/itemeditors.php',
            'administrator/components/com_autotweet/controllers/managers.php',
            'administrator/components/com_autotweet/controllers/scoopitchannels.php',
            'administrator/components/com_autotweet/controllers/targets.php',
            'administrator/components/com_autotweet/controllers/tumblrchannels.php',
            'administrator/components/com_autotweet/controllers/xingchannels.php',
            'administrator/components/com_autotweet/helpers/advancedattrs.php',
            'administrator/components/com_autotweet/helpers/channels/pinterest.php',
            'administrator/components/com_autotweet/helpers/channels/pagespeed.php',
            'administrator/components/com_autotweet/helpers/channels/blogger.php',
            'administrator/components/com_autotweet/helpers/channels/easysocial.php',
            'administrator/components/com_autotweet/helpers/channels/jomsocial.php',
            'administrator/components/com_autotweet/helpers/channels/scoopit.php',
            'administrator/components/com_autotweet/helpers/channels/Scoopit/README',
            'administrator/components/com_autotweet/helpers/channels/Scoopit/ScoopIt.php',
            'administrator/components/com_autotweet/helpers/channels/tumblr.php',
            'administrator/components/com_autotweet/helpers/channels/xing.php',
            'administrator/components/com_autotweet/helpers/virtualmanager.php',
            'administrator/components/com_autotweet/models/feedk2.php',
            'administrator/components/com_autotweet/models/feedk2categories.php',
            'administrator/components/com_autotweet/models/feedzoo.php',
            'administrator/components/com_autotweet/models/feedzoocategories.php',
            'administrator/components/com_autotweet/models/managers.php',
            'administrator/components/com_autotweet/models/targets.php',
            'administrator/components/com_autotweet/models/userchannels.php',
            'administrator/components/com_autotweet/tables/target.php',
            'administrator/components/com_autotweet/tables/userchannel.php',
            'administrator/components/com_autotweet/vendor/google/apiclient-services/Google/Service/Blogger.php',
            'administrator/components/com_autotweet/vendor/google/apiclient-services/Google/Service/Pagespeedonline.php',
            'administrator/components/com_autotweet/views/channel/tmpl/bloggerchannel-post.php',
            'administrator/components/com_autotweet/views/channel/tmpl/mediumchannel-post.php',
            'administrator/components/com_autotweet/views/channel/tmpl/tumblrchannel-post.php',
            'components/com_autotweet/controllers/userchannels.php',
            'components/com_autotweet/views/channel/tmpl/bloggerchannel-post.php',
            'components/com_autotweet/views/channel/tmpl/form.php',
            'components/com_autotweet/views/channel/tmpl/mediumchannel-post.php',
            'components/com_autotweet/views/channel/tmpl/tumblrchannel-post.php',
            'components/com_autotweet/views/channels',
            'components/com_autotweet/views/composer',
            'components/com_autotweet/views/cpanels',
            'components/com_autotweet/views/fbchannel',
            'components/com_autotweet/views/itemeditor',
            'components/com_autotweet/views/ligroupchannel',
            'components/com_autotweet/views/lioauth2channel',
            'components/com_autotweet/views/lioauth2companychannel',
            'components/com_autotweet/views/nochannel',
            'components/com_autotweet/views/notauths',
            'components/com_autotweet/views/post',
            'components/com_autotweet/views/posts',
            'components/com_autotweet/views/request/tmpl/form.php',
            'components/com_autotweet/views/request/view.html.php',
            'components/com_autotweet/views/requests/tmpl/default.php',
            'components/com_autotweet/views/requests/view.html.php',
            'components/com_autotweet/views/twchannel',
            'components/com_autotweet/views/userchannels',
            'components/com_autotweet/views/vkchannel',
            'media/com_autotweet/fullcalendar',
            'media/com_autotweet/js/itemeditor-tab.js',
            'media/com_autotweet/js/itemeditor-tab.min.js',
            'media/com_autotweet/js/itemeditor.js',
            'media/com_autotweet/js/itemeditor.min.js',
            'media/com_autotweet/js/jootool.helper.min.js',
            'media/com_autotweet/js/jootool.js',
            'media/com_autotweet/js/jootool.min.js',
            'media/com_autotweet/js/manager.js',
            'media/com_autotweet/js/manager.min.js',
            'media/com_autotweet/js/target.js',
            'media/com_autotweet/js/target.min.js',
            'media/com_autotweet/js/userchannel.js',
            'media/com_autotweet/js/userchannel.min.js',

            // Vendor Update
            'administrator/components/com_autotweet/vendor/illuminate/contracts/Auth/Registrar.php',
            'administrator/components/com_autotweet/vendor/illuminate/contracts/Bus/SelfHandling.php',
            'administrator/components/com_autotweet/vendor/illuminate/contracts/Pagination/Presenter.php',
            'administrator/components/com_autotweet/vendor/illuminate/contracts/Validation/UnauthorizedException.php',
            'administrator/components/com_autotweet/vendor/illuminate/contracts/Validation/ValidationException.php'

        ),
        'folders' => array(
			// Migration to Prefixed Libraries
			'administrator/components/com_autotweet/libs',
			'administrator/components/com_autotweet/vendor',

            // Deprecated
            'administrator/components/com_autotweet/helpers/channels/facebook-php-sdk',
            'administrator/components/com_autotweet/helpers/channels/google',
            'administrator/components/com_autotweet/helpers/channels/Scoopit',
            'administrator/components/com_autotweet/helpers/channels/Simple-LinkedIn',
            'administrator/components/com_autotweet/helpers/channels/tmhOAuth',
            'administrator/components/com_autotweet/helpers/channels/VK',
            'administrator/components/com_autotweet/helpers/channels/xingoauth',
            'administrator/components/com_autotweet/views/gpluschannel',
            'administrator/components/com_autotweet/views/lichannel',
            'administrator/components/com_autotweet/views/licompanychannel',
            'components/com_autotweet/views/gpluschannel',
            'components/com_autotweet/views/lichannel',
            'components/com_autotweet/views/licompanychannel',

            // Joocial Reset
            'administrator/components/com_autotweet/helpers/channels/Scoopit',
            'administrator/components/com_autotweet/helpers/channels/tumblroauth',
            'administrator/components/com_autotweet/helpers/channels/xingoauth',
            'administrator/components/com_autotweet/helpers/JgOAuth',
            'administrator/components/com_autotweet/layouts/joocial',
			'administrator/components/com_autotweet/vendor/doctrine',
			'administrator/components/com_autotweet/vendor/facebook/facebook-instant-articles-sdk-php',
			'administrator/components/com_autotweet/vendor/google/apiclient-services/Google/Service/Blogger',
			'administrator/components/com_autotweet/vendor/google/apiclient-services/Google/Service/Pagespeedonline',
			'administrator/components/com_autotweet/vendor/irazasyed',
			'administrator/components/com_autotweet/vendor/norkunas',
            'administrator/components/com_autotweet/views/bloggerchannel',
            'administrator/components/com_autotweet/views/pagespeedchannel',
            'administrator/components/com_autotweet/views/pinterestchannel',
            'administrator/components/com_autotweet/views/calendar',
            'administrator/components/com_autotweet/views/easysocialchannel',
            'administrator/components/com_autotweet/views/evergreens',
            'administrator/components/com_autotweet/views/itemeditor',
            'administrator/components/com_autotweet/views/jomsocialchannel',
            'administrator/components/com_autotweet/views/manager',
            'administrator/components/com_autotweet/views/mediumchannel',
            'administrator/components/com_autotweet/views/onesignalchannel',
            'administrator/components/com_autotweet/views/pushwooshchannel',
            'administrator/components/com_autotweet/views/scoopitchannel',
            'administrator/components/com_autotweet/views/target',
            'administrator/components/com_autotweet/views/targets',
            'administrator/components/com_autotweet/views/telegramchannel',
            'administrator/components/com_autotweet/views/tumblrchannel',
            'administrator/components/com_autotweet/views/xingchannel',
            'components/com_autotweet/views/bloggerchannel',
            'components/com_autotweet/views/channels',
            'components/com_autotweet/views/composer',
            'components/com_autotweet/views/cpanels',
            'components/com_autotweet/views/easysocialchannel',
            'components/com_autotweet/views/fbchannel',
            'components/com_autotweet/views/itemeditor',
            'components/com_autotweet/views/jomsocialchannel',
            'components/com_autotweet/views/ligroupchannel',
            'components/com_autotweet/views/lioauth2channel',
            'components/com_autotweet/views/lioauth2companychannel',
            'components/com_autotweet/views/mediumchannel',
            'components/com_autotweet/views/nochannel',
            'components/com_autotweet/views/notauths',
			'components/com_autotweet/views/onesignalchannel',
			'components/com_autotweet/views/pushwooshchannel',
            'components/com_autotweet/views/post',
            'components/com_autotweet/views/posts',
            'components/com_autotweet/views/scoopitchannel',
            'components/com_autotweet/views/telegramchannel',
            'components/com_autotweet/views/tumblrchannel',
            'components/com_autotweet/views/twchannel',
            'components/com_autotweet/views/userchannels',
            'components/com_autotweet/views/vkchannel',
            'components/com_autotweet/views/xingchannel',
            'media/com_autotweet/fullcalendar',
            'media/com_autotweet/js/itemeditor',
            'media/com_autotweet/js/jootool',
            'media/com_autotweet/js/liveupdate',
            'media/com_autotweet/js/target',
            'media/com_autotweet/js/userchannel',

            // Vendor Update
            'administrator/components/com_autotweet/vendor/facebook/facebook-instant-articles-sdk-php/.github',
            'administrator/components/com_autotweet/vendor/facebook/php-sdk-v4',
            'administrator/components/com_autotweet/vendor/google/apiclient-services/Google'
        )
    );

    /**
     * A list of scripts to be copied to the "cli" directory of the site
     *
     * @var   array
     */
    protected $cliScriptFiles = array(
        'autotweetstartcronjob.php'
    );

    /**
     * Post-installation message definitions for Joomla! 3.2 or later.
     *
     * This array contains the message definitions for the Post-installation Messages component added in Joomla! 3.2 and
     * later versions. Each element is also a hashed array. For the keys used in these message definitions please
     * @see F0FUtilsInstallscript::addPostInstallationMessage
     *
     * @var array
     */
    protected $postInstallationMessages = array(
        'autojupdate' => array(
            'type'                    => 'action',
            'title_key'                => 'COM_AUTOTWEET_POSTSETUP_LBL_AUTOJUPDATE',
            'description_key'        => 'COM_AUTOTWEET_POSTSETUP_DESC_AUTOJUPDATE2',
            'action_key'            => 'COM_AUTOTWEET_POSTSETUP_BTN_ENABLE_FEATURE',
            'language_extension'    => 'com_autotweet',
            'language_client_id'    => '1',
            'version_introduced'    => 'EXTLY_BUILD_VERSION',
            'condition_file'        => 'admin://components/com_autotweet/helpers/postinstall.php',
            'condition_method'        => 'Com_AutoTweet_PostInstall_AutoJUpdate_condition',
            'action_file'            => 'admin://components/com_autotweet/helpers/postinstall.php',
            'action'                => 'Com_AutoTweet_PostInstall_AutoJUpdate_action',
        ),
        'accept_license' => array(
            'type'                    => 'message',
            'title_key'                => 'COM_AUTOTWEET_POSTSETUP_LBL_ACCEPTLICENSE',
            'description_key'        => 'COM_AUTOTWEET_POSTSETUP_DESC_ACCEPTLICENSE',
            'action_key'            => 'COM_AUTOTWEET_POSTSETUP_BTN_I_CONFIRM_THIS',
            'language_extension'    => 'com_autotweet',
            'language_client_id'    => '1',
            'version_introduced'    => 'EXTLY_BUILD_VERSION'
        ),
        'accept_support' => array(
            'type'                    => 'message',
            'title_key'                => 'COM_AUTOTWEET_POSTSETUP_LBL_ACCEPTSUPPORT',
            'description_key'        => 'COM_AUTOTWEET_POSTSETUP_DESC_ACCEPTSUPPORT',
            'action_key'            => 'COM_AUTOTWEET_POSTSETUP_BTN_I_CONFIRM_THIS',
            'language_extension'    => 'com_autotweet',
            'language_client_id'    => '1',
            'version_introduced'    => 'EXTLY_BUILD_VERSION'
        ),
    );

    /**
     * Installs Extly Strapper if necessary
     *
     * @param   JInstaller  $parent  The parent object
     *
     * @return  array  The installation status
     */
    protected function installStrapper($parent)
    {
        $src = $parent->getParent()->getPath('source');
        $source = $src . '/' . $this->strapperSourcePath . '/lib_extly';

        $target = JPATH_ROOT . '/libraries/extly';

        if (!JFolder::exists($source)) {
            return array(
                    'required'  => false,
                    'installed' => false,
                    'version'   => '0.0.0',
                    'date'      => '2011-01-01',
            );
        }

        $haveToInstallStrapper = false;

        if (!JFolder::exists($target)) {
            $haveToInstallStrapper = true;
        } else {
            $strapperVersion = array();

            if (JFile::exists($target . '/version.txt')) {
                $rawData = JFile::read($target . '/version.txt');
                $rawData = ($rawData === false) ? "0.0.0\n2011-01-01\n" : $rawData;
                $info = explode("\n", $rawData);
                $strapperVersion['installed'] = array(
                        'version' => trim($info[0]),
                        'date'    => new JDate(trim($info[1]))
                );
            } else {
                $strapperVersion['installed'] = array(
                        'version' => '0.0',
                        'date'    => new JDate('2011-01-01')
                );
            }

            $rawData = JFile::read($source . '/version.txt');
            $rawData = ($rawData === false) ? "0.0.0\n2011-01-01\n" : $rawData;
            $info = explode("\n", $rawData);
            $strapperVersion['package'] = array(
                    'version' => trim($info[0]),
                    'date'    => new JDate(trim($info[1]))
            );

            $haveToInstallStrapper = $strapperVersion['package']['date']->toUNIX() > $strapperVersion['installed']['date']->toUNIX();
        }

        $installedStraper = false;

        if ($haveToInstallStrapper) {
            $versionSource = 'package';
            $installer = new JInstaller;
            $installedStraper = $installer->install($source);
        } else {
            $versionSource = 'installed';
        }

        if (!isset($strapperVersion)) {
            $strapperVersion = array();

            if (JFile::exists($target . '/version.txt')) {
                $rawData = JFile::read($target . '/version.txt');
                $rawData = ($rawData === false) ? "0.0.0\n2011-01-01\n" : $rawData;
                $info = explode("\n", $rawData);
                $strapperVersion['installed'] = array(
                        'version' => trim($info[0]),
                        'date'    => new JDate(trim($info[1]))
                );
            } else {
                $strapperVersion['installed'] = array(
                        'version' => '0.0',
                        'date'    => new JDate('2011-01-01')
                );
            }

            $rawData = JFile::read($source . '/version.txt');
            $rawData = ($rawData === false) ? "0.0.0\n2011-01-01\n" : $rawData;
            $info = explode("\n", $rawData);

            $strapperVersion['package'] = array(
                    'version' => trim($info[0]),
                    'date'    => new JDate(trim($info[1]))
            );

            $versionSource = 'installed';
        }

        if (!($strapperVersion[$versionSource]['date'] instanceof JDate)) {
            $strapperVersion[$versionSource]['date'] = new JDate;
        }

        return array(
                'required'  => $haveToInstallStrapper,
                'installed' => $installedStraper,
                'version'   => $strapperVersion[$versionSource]['version'],
                'date'      => $strapperVersion[$versionSource]['date']->format('Y-m-d'),
        );
    }

    /**
     * Runs after install, update or discover_update. In other words, it executes after Joomla! has finished installing
     * or updating your component. This is the last chance you've got to perform any additional installations, clean-up,
     * database updates and similar housekeeping functions.
     *
     * @param   string      $type    install, update or discover_update
     * @param   JInstaller  $parent  Parent object
     *
     * @return void
     */
    public function postflight($type, $parent)
    {
        $this->isPaid = is_dir(JPATH_ROOT . '/administrator/components/com_autotweet/helpers/channels/Scoopit');
        $this->renderType = $type;

        if (!$this->isPaid) {
            unset($this->postInstallationMessages['autojupdate']);
        }

        parent::postflight($type, $parent);
    }

    /**
     * Renders the post-installation message
     *
     * @param   bool        $status                      Param
     * @param   bool        $fofInstallationStatus       Param
     * @param   bool        $strapperInstallationStatus  Param
     * @param   JInstaller  $parent                      Parent object
     *
     * @return void
     */
    public function renderPostInstallation($status, $fofInstallationStatus, $strapperInstallationStatus, $parent)
    {
        $this->warnAboutJSNPowerAdmin();
        $this->_renderPostInstallation($status, $fofInstallationStatus, $strapperInstallationStatus, $parent);
    }

    /**
     * Renders the message after installing or upgrading the component
     *
     * @param   bool        $status                      Param
     * @param   bool        $fofInstallationStatus       Param
     * @param   bool        $strapperInstallationStatus  Param
     * @param   JInstaller  $parent                      Parent object
     *
     * @return void
     */
    private function _renderPostInstallation($status, $fofInstallationStatus, $strapperInstallationStatus, $parent)
    {
        $rows = 0;

        if ($this->renderType == 'update') {
            ?>
		<div class="alert alert-warning">
  			<button type="button" class="close" data-dismiss="alert">&times;</button>
  				<strong>Warning! If you have manually installed optional plugins, you must also manually update them. Please, review the latest versions,
 				<a href="index.php?option=com_autotweet&view=infos">here <i class="icon-link"></i></a>.</strong>
  		</div>
<?php

        } ?>

		<img src="<?php echo JUri::root(); ?>media/com_autotweet/images/autotweet-logo.png"
			width="57" height="57" alt="Extly - Joomla Extensions" align="right" />

		<h2><?php echo $this->componentTitle; ?> Installation Status</h2>

		<p>
			<strong>Enhance your social media management!</strong>
		</p>
		<table class="adminlist table table-striped" width="100%">
			<thead>
			<tr>
				<th class="title" colspan="2">Extension</th>
				<th width="30%">Status</th>
			</tr>
			</thead>
			<tfoot>
			<tr>
				<td colspan="3"></td>
			</tr>
			</tfoot>
			<tbody>
			<tr class="row<?php

            echo $rows % 2;
        $rows++; ?>">
				<td class="key" colspan="2"><?php echo $this->componentTitle ?></td>
				<td><strong style="color: green">Installed</strong></td>
			</tr>
			<?php

            if ($fofInstallationStatus['required']) {
                ?>
				<tr class="row<?php

                echo $rows % 2;
                $rows++; ?>">
					<td class="key" colspan="2">
						<strong>Framework on Framework (FOF) <?php echo $fofInstallationStatus['version'] ?></strong>
						[<?php echo $fofInstallationStatus['date'] ?>]
					</td>
					<td><strong>
							<span
								style="color: <?php echo $fofInstallationStatus['required'] ? ($fofInstallationStatus['installed'] ? 'green' : 'red') : '#660' ?>; font-weight: bold;">
		<?php echo $fofInstallationStatus['required'] ? ($fofInstallationStatus['installed'] ? 'Installed' : 'Not Installed') : 'Already up-to-date'; ?>
							</span>
						</strong></td>
				</tr>
			<?php

            } ?>
			<?php

            if ($strapperInstallationStatus['required']) {
                ?>
				<tr class="row<?php

                echo $rows % 2;
                $rows++; ?>">
					<td class="key" colspan="2">
						<strong>Extly Framework <?php echo $strapperInstallationStatus['version'] ?></strong>
						[<?php echo $strapperInstallationStatus['date'] ?>]
					</td>
					<td><strong>
							<span
								style="color: <?php echo $strapperInstallationStatus['required'] ? ($strapperInstallationStatus['installed'] ? 'green' : 'red') : '#660' ?>; font-weight: bold;">
				<?php echo $strapperInstallationStatus['required'] ? ($strapperInstallationStatus['installed'] ? 'Installed' : 'Not Installed') : 'Already up-to-date'; ?>
							</span>
						</strong></td>
				</tr>
			<?php

            }

        if (count($status->modules)) {
            ?>
				<tr>
					<th>Module</th>
					<th>Client</th>
					<th></th>
				</tr>
				<?php

                foreach ($status->modules as $module) {
                    ?>
					<tr class="row<?php

                    echo $rows % 2;
                    $rows++; ?>">
						<td class="key"><?php echo $module['name']; ?></td>
						<td class="key"><?php echo ucfirst($module['client']); ?></td>
						<td><strong
								style="color: <?php

                                echo $module['result'] ? "green" : "red"; ?>"><?php

                                echo $module['result'] ? 'Installed' : 'Not installed'; ?></strong>
						</td>
					</tr>
				<?php

                }
        }

        if (count($status->plugins)) {
            ?>
				<tr>
					<th>Plugin</th>
					<th>Group</th>
					<th></th>
				</tr>
				<?php

                foreach ($status->plugins as $plugin) {
                    ?>
					<tr class="row<?php

                    echo $rows % 2;
                    $rows++; ?>">
						<td class="key"><?php echo ucfirst($plugin['name']); ?></td>
						<td class="key"><?php echo ucfirst($plugin['group']); ?></td>
						<td><strong
								style="color: <?php

                                echo $plugin['result'] ? "green" : "red"

                                ?>"><?php

                                echo $plugin['result'] ? 'Installed' : 'Not installed'; ?></strong>
						</td>
					</tr>
				<?php

                }
        } ?>
			</tbody>
		</table>

		<fieldset>

			<h2>Tutorials</h2>

			<h3>Tutorial: How to AutoTweet from Joomla in 5 minutes</h3>
			<p><a target="_blank" href="https://www.extly.com/docs/autotweetng_joocial/tutorials/how-to-autotweet">
				<img alt="How to AutoTweet from Joomla in 5 minutes"
					src="//www.extly.com/images/autotweet-documentation/How_to_AutoTweet_from_Joomla_in_5_minutes.jpg" height="300" width="480" /></a></p>

			<h3>Tutorial: Joocial - Full social content management in Joomla</h3>
			<p><a target="_blank" href="https://www.extly.com/docs/autotweetng_joocial/tutorials/#joocial-full-management-of-social-content-in-joomla">
				<img alt="Tutorial: Joocial - Full social content management in Joomla"
					src="//d3hptxmced6nen.cloudfront.net/images/autotweet-documentation/Joocial_Full_Social_Content_Management_2015.png" width="480" /></a></p>

			<h3>Documentation: AutoTweetNG and Joocial - Introduction</h3>
			<p><a target="_blank" href="https://www.extly.com/docs/autotweetng_joocial/index.html">
				Tutorials and Recipes</a></p>

			<hr />

			<p>
				If you have any question, please, don't hesitate to contact us.<br /> Technical Support:
					<a href="https://support.extly.com" target="_blank">https://support.extly.com</a>
			</p>

			<p>
				We are passionately committed to your success.<br /> Support Team<br />
				<strong>Extly.com - Extensions</strong><br /> <a href="https://support.extly.com" target="_blank">https://support.extly.com</a>
				| <a href="http://twitter.com/extly" target="_blank">@extly</a> | <a href="http://www.facebook.com/extly" target="_blank">facebook.com/extly</a>
			</p>

		</fieldset>
	<?php

    }

    /**
     * Uninstalls subextensions (modules, plugins) bundled with the main extension
     *
     * @param   JInstaller  $parent  The parent object
     *
     * @return  stdClass  The subextension uninstallation status
     */
    protected function uninstallSubextensions($parent)
    {
        $db = JFactory::getDBO();

        $query = 'SELECT type, folder, element, client_id FROM ' . $db->quoteName('#__extensions')
            . ' WHERE (' .
            $db->quoteName('type') . ' = ' . $db->Quote('plugin') . ') AND (' .

            $db->quoteName('element') . ' like ' . $db->Quote('%autotweet%') . ' OR ' .
            $db->quoteName('name') . ' like ' . $db->Quote('%AutoTweet%') . ' OR ' .
            $db->quoteName('element') . ' like ' . $db->Quote('%joocial%') . ' OR ' .
            $db->quoteName('name') . ' like ' . $db->Quote('%Joocial%')

            . ')' .    ' ORDER BY ' . $db->quoteName('extension_id');

        $db->setQuery($query);
        $extensions = $db->loadAssocList();

        foreach ($extensions as $ext) {
            $type = $ext['type'];
            $folder = $ext['folder'];
            $element = $ext['element'];
            $client_id = $ext['client_id'];

            /*
            if ($type == 'module')
            {
                Admin
                if ($client_id == 1)
                {
                    if (!isset($this->installation_queue['modules']['admin'][$element]))
                    {
                        $this->installation_queue['modules']['admin'][$element] = 1;
                    }
                }
                else
                {
                    Site
                    if (!isset($this->installation_queue['modules']['site'][$element]))
                    {
                        $this->installation_queue['modules']['site'][$element] = 1;
                    }
                }
            }
            */

            if ($type == 'plugin') {
                if (!isset($this->installation_queue['plugins'][$folder][$element])) {
                    $this->installation_queue['plugins'][$folder][$element] = 1;
                }
            }
        }

        return parent::uninstallSubextensions($parent);
    }

    /**
     * renderPostUninstallation
     *
     * @param   bool        $status  Param
     * @param   JInstaller  $parent  Parent object
     *
     * @return void
     */
    protected function renderPostUninstallation($status, $parent)
    {
        ?>
		<h2><?php echo $this->componentTitle; ?> Uninstallation Status</h2>
		<?php
        parent::renderPostUninstallation($status, $parent);
    }

    /**
     * warnAboutJSNPowerAdmin
     *
     * The PowerAdmin extension makes menu items disappear. People assume it's our fault. JSN PowerAdmin authors don't
     * own up to their software's issue. I have no choice but to warn our users about the faulty third party software.
     *
     * @return void
     */
    private function warnAboutJSNPowerAdmin()
    {
        $db = JFactory::getDbo();
        $query = $db->getQuery(true)
            ->select('COUNT(*)')
            ->from($db->qn('#__extensions'))
            ->where($db->qn('type') . ' = ' . $db->q('component'))
            ->where($db->qn('element') . ' = ' . $db->q('com_poweradmin'))
            ->where($db->qn('enabled') . ' = ' . $db->q('1'));
        $hasPowerAdmin = $db->setQuery($query)->loadResult();

        if (!$hasPowerAdmin) {
            return;
        }

        $query = $db->getQuery(true)
                    ->select('manifest_cache')
                    ->from($db->qn('#__extensions'))
                    ->where($db->qn('type') . ' = ' . $db->q('component'))
                    ->where($db->qn('element') . ' = ' . $db->q('com_poweradmin'))
                    ->where($db->qn('enabled') . ' = ' . $db->q('1'));
        $paramsJson = $db->setQuery($query)->loadResult();
        $jsnPAManifest = new JRegistry;
        $jsnPAManifest->loadString($paramsJson, 'JSON');
        $version = $jsnPAManifest->get('version', '0.0.0');

        if (version_compare($version, '2.1.2', 'ge')) {
            return;
        }

        echo <<< HTML
<div class="well" style="margin: 2em 0;">
<h1 style="font-size: 32pt; line-height: 120%; color: red; margin-bottom: 1em">
	WARNING: Menu items for {$this->componentName} might not be displayed on your site.</h1>
<p style="font-size: 18pt; line-height: 150%; margin-bottom: 1.5em">
	We have detected that you are using JSN PowerAdmin on your site. This software ignores Joomla! standards and
	<b>hides</b> the Component menu items to {$this->componentName} in the administrator backend of your site. Unfortunately we
	can't provide support for third party software. Please contact the developers of JSN PowerAdmin for support
	regarding this issue.
</p>
<p style="font-size: 18pt; line-height: 120%; color: green;">
	Tip: You can disable JSN PowerAdmin to see the menu items to {$this->componentName}.
</p>
</div>

HTML;
    }
}
